@@ -1,5 +1,5 @@
 import logging
-from typing import Dict, List, Optional
+from typing import Any, Dict, List, Optional
 
 from aporia.core.http_client import HttpClient
 from aporia.core.logging_utils import LOGGER_NAME
@@ -22,7 +22,8 @@ async def run_create_model_version_query(
     model_data_type: Optional[str] = None,
     labels: Optional[List[str]] = None,
     feature_importance: Optional[Dict[str, float]] = None,
-    mapping: Optional[Dict[str, str]] = None
+    mapping: Optional[Dict[str, str]] = None,
+    datasets: Optional[Dict[str, Any]] = None,
 ):
     """Defines the schema for a specific model version.
 
@@ -38,11 +39,14 @@ async def run_create_model_version_query(
         model_data_type: Model data type.
         labels: Labels of multi-label, multiclass or binary model.
         feature_importance: Features' importance.
+        mapping: General mapping. See Notes.
+        datasets: Datasets configuration.
 
-        mapping: General mapping. Allowed fields are:
-        * batch_id_column_name: The name of the key in the `raw_inputs` dict that holds the value of the `batch_id`.
-        * relevance_column_name: The name of the key in the `predictions` dict that holds the value of the `relevance` score of models of type `ranking`.
-        * actual_relevance_column_name: The name of the key in the `actuals` dict that holds the value of the `relevance` score of models of type `ranking`.
+    Notes:
+        Allowed mapping fields are:
+            * batch_id_column_name: The name of the key in the `raw_inputs` dict that holds the value of the `batch_id`.
+            * relevance_column_name: The name of the key in the `predictions` dict that holds the value of the `relevance` score of models of type `ranking`.
+            * actual_relevance_column_name: The name of the key in the `actuals` dict that holds the value of the `relevance` score of models of type `ranking`.
     """
     model_version_input = {
         "name": model_version,
@@ -58,6 +62,7 @@ async def run_create_model_version_query(
         "labels": labels,
         "feature_importance": feature_importance,
         "mapping": mapping,
+        "datasets": datasets,
     }
 
     await http_client.post(
