@@ -218,7 +218,8 @@ def create_model_version(
     labels: Optional[List[str]] = None,
     multiclass_labels: Optional[List[str]] = None,
     feature_importance: Optional[Dict[str, float]] = None,
-    mapping: Optional[Dict[str, str]] = None
+    mapping: Optional[Dict[str, str]] = None,
+    datasets: Optional[Dict[str, Any]] = None,
 ) -> Optional[Model]:
     """Creates a new model version, and defines a schema for it.
 
@@ -227,19 +228,16 @@ def create_model_version(
         model_version: Model version - this can be any string that represents the model
             version, such as "v1" or a git commit hash.
         model_type: Model type (also known as objective - see notes).
-        features: Schema for model features (See notes)
-        predictions: Schema for prediction results (See notes)
+        features: Schema for model features (See notes).
+        predictions: Schema for prediction results (See notes).
         raw_inputs: Schema for raw inputs (See notes).
         metrics: Schema for prediction metrics (See notes).
         model_data_type: Model data type.
         labels: Labels of multi-label, multiclass or binary model. Takes precedence over "multiclass_labels".
         multiclass_labels: Labels of multi-label, multiclass or binary model. Same as "labels", Deprecated.
         feature_importance: Features' importance.
-
-        mapping: General mapping. Allowed fields are:
-        * batch_id_column_name: The name of the key in the `raw_inputs` dict that holds the value of the `batch_id`.
-        * relevance_column_name: The name of the key in the `predictions` dict that holds the value of the `relevance` score of models of type `ranking`.
-        * actual_relevance_column_name: The name of the key in the `actuals` dict that holds the value of the `relevance` score of models of type `ranking`.
+        mapping: General mapping (See notes).
+        datasets: Datasets configuration.
 
     Notes:
         * A schema is a dict, in which the keys are the fields you wish to report, and the
@@ -255,6 +253,7 @@ def create_model_version(
             * "binary" - for binary classification models
             * "multiclass" - for multiclass classification models
             * "multi-label" - for multi-label classification models
+            * "ranking" - for ranking models
         * The valid field types (and corresponding python types) are:
 
             | Field Type    | Python Types
@@ -277,6 +276,10 @@ def create_model_version(
                 "feature2": 2
              }
           ```
+        * The mapping allowed fields are:
+            * batch_id_column_name: The name of the key in the `raw_inputs` dict that holds the value of the `batch_id`.
+            * relevance_column_name: The name of the key in the `predictions` dict that holds the value of the `relevance` score of models of type `ranking`.
+            * actual_relevance_column_name: The name of the key in the `actuals` dict that holds the value of the `relevance` score of models of type `ranking`.
 
     Returns:
         Model object for the new version.
@@ -306,7 +309,8 @@ def create_model_version(
             metrics=metrics,
             labels=labels if labels is not None else multiclass_labels,
             feature_importance=feature_importance,
-            mapping=mapping
+            mapping=mapping,
+            datasets=datasets,
         )
     )
 
