@@ -1,3 +1,4 @@
+import asyncio
 from http import HTTPStatus
 import logging
 import re
@@ -61,7 +62,7 @@ class HttpClient:
     async def open(self):
         """Opens the HTTP session."""
         logger.debug("Creating HTTP session with Aporia server.")
-        self.session = aiohttp.ClientSession(headers=self.headers)
+        self.session = aiohttp.ClientSession(headers=self.headers, trust_env=True)
 
     async def graphql(
         self,
@@ -174,14 +175,17 @@ class HttpClient:
         """
         num_attempts = REQUEST_MAX_ATTEMPTS if retry_on_failure else 1
         timeout = timeout if timeout is not None else self.default_timeout
-        async for attempt in AsyncRetrying(
-            stop=stop_after_attempt(num_attempts),
-            wait=wait_exponential(min=REQUEST_RETRY_INITIAL_SLEEP),
-            retry=retry_if_exception(lambda err: not isinstance(err, AporiaError)),
-            reraise=True,
-        ):
-            with attempt:
-                return await self._request(method=method, url=url, data=data, timeout=timeout)
+        try:
+            async for attempt in AsyncRetrying(
+                stop=stop_after_attempt(num_attempts),
+                wait=wait_exponential(min=REQUEST_RETRY_INITIAL_SLEEP),
+                retry=retry_if_exception(lambda err: not isinstance(err, AporiaError)),
+                reraise=True,
+            ):
+                with attempt:
+                    return await self._request(method=method, url=url, data=data, timeout=timeout)
+        except asyncio.TimeoutError:
+            raise AporiaError("Request timed out")
 
     async def _request(
         self, method: str, url: str, data: Optional[dict] = None, timeout: Optional[int] = None
