@@ -212,9 +212,7 @@ class InferenceModel(BaseModel):
 
             if self._config.verbose:
                 for i, fragment in enumerate(fragments):
-                    if fragment.is_valid():
-                        logger.debug("{} {} is valid".format(fragment.type.value, i))
-                    else:
+                    if not fragment.is_valid():
                         logger.warning("{} {} is not valid".format(fragment.type.value, i))
 
             count = self._event_loop.run_coroutine(self._queue.put(fragments=fragments))
