@@ -85,6 +85,7 @@ class Model(InferenceModel):
         features: Union[DataFrame, ndarray],  # type: ignore
         labels: DataFrame,  # type: ignore
         raw_inputs: Optional[DataFrame] = None,  # type: ignore
+        sample: bool = True,
     ):
         """Logs aggregations of the whole set and logs a sample of the data.
 
@@ -92,6 +93,7 @@ class Model(InferenceModel):
             features: Training set features
             labels: Training set labels
             raw_inputs: Training set raw inputs.
+            sample: Whether to log a sample of the data.
 
         Notes:
             * Each dataframe corresponds to a field category defined in create_model_version:
@@ -114,14 +116,25 @@ class Model(InferenceModel):
                     ),
                 )
 
-            self._training.log_training_set(features=features, labels=labels, raw_inputs=raw_inputs)
+            self._training.log_training_set(
+                features=features,
+                labels=labels,
+                raw_inputs=raw_inputs,
+                sample=sample,
+            )
 
-    def log_training_sample(self, features: Union[DataFrame, ndarray], labels: DataFrame):  # type: ignore
+    def log_training_sample(
+        self,
+        features: Union[DataFrame, ndarray],  # type: ignore
+        labels: DataFrame,  # type: ignore
+        raw_inputs: Optional[DataFrame] = None,  # type: ignore
+    ):
         """Logs a sample of the training data.
 
         Args:
             features: Training set features
             labels: Training set labels
+            raw_inputs: Training set raw_inputs
 
         Notes:
             * Each dataframe corresponds to a field category defined in create_model_version:
@@ -143,7 +156,9 @@ class Model(InferenceModel):
                     ),
                 )
 
-            self._training.log_training_sample(features=features, labels=labels)
+            self._training.log_training_data(
+                features=features, labels=labels, raw_inputs=raw_inputs
+            )
 
     def log_test_set(
         self,
