@@ -213,6 +213,7 @@ async def log_training_sample_data(
     model_version: str,
     features: List[Dict[str, Any]],
     labels: List[Any],
+    raw_inputs: Optional[List[Any]] = None,
 ):
     """Reports training sample.
 
@@ -222,8 +223,9 @@ async def log_training_sample_data(
         model_version: Mode version.
         features: List of features.
         labels: List of labels.
+        raw_inputs: List of raw inputs.
     """
     await http_client.post(
         url=f"/models/{model_id}/versions/{model_version}/training_sample",
-        data={"features": features, "labels": labels},
+        data={"features": features, "labels": labels, "raw_inputs": raw_inputs},
     )
